@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:51:10
-@LastEditTime: 2022-05-20 16:46:02
+@LastEditTime: 2022-06-14 15:46:59
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -29,7 +29,8 @@ class AppExpireHandler(ClientBaseHandler):
         invoke_result_data = app_base_model.get_app_expire(app_id)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params={}))
 
 
 class AddWechatSubscribeHandler(ClientBaseHandler):
@@ -48,7 +49,7 @@ class AddWechatSubscribeHandler(ClientBaseHandler):
         invoke_result_data = push_base_model.add_wechat_subscribe(app_id)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data,ref_params={}))
 
 
 class CreateWeChatQrCodeHandler(ClientBaseHandler):
@@ -110,4 +111,4 @@ class GetHighPowerListHandler(ClientBaseHandler):
             custom_function_list = list(filter(lambda custom_function: custom_function["app_id"] == app_id, custom_function_list))
             if len(custom_function_list) > 0:
                 config_data["function_config_list"] = query(custom_function_list[0]["function_info_second_list"]).select(lambda x: {"name": x["name"], "key_name": x["key_name"]}).to_list()
-        self.response_json_success(config_data)
\ No newline at end of file
+        self.response_json_success(self.business_process_executed(config_data, ref_params={}))
