@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 09:24:50
-@LastEditTime: 2022-01-21 21:27:18
+@LastEditTime: 2022-06-14 15:47:20
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -48,7 +48,7 @@ class SkuInfoHandler(ClientBaseHandler):
             if not act_prize:
                 return self.response_json_error("error", "对不起，找不到该商品的sku")
             sku_detail = self.json_loads(act_prize['sku_json'])
-            return self.response_json_success(sku_detail["items_seller_list_get_response"])
+            return self.response_json_success(self.business_process_executed(sku_detail["items_seller_list_get_response"], ref_params={}))
 
 
 class GoodsListHandler(ClientBaseHandler):
@@ -78,4 +78,4 @@ class GoodsListHandler(ClientBaseHandler):
         invoke_result_data = top_base_model.get_goods_list(page_index, page_size, "", "", "", app_info_dict["access_token"], app_key, app_secret, is_log=is_log)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params={}))
