@@ -2,13 +2,15 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-04-27 16:11:04
+@LastEditTime: 2022-06-23 19:08:53
 @LastEditors: HuangJianYi
 @Description: 
 """
+from operator import truediv
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
+from seven_cloudapp_frame.libs.customize.alipay_helper import AliPayRequest
 from seven_cloudapp_frame.models.shakeshop_base_model import *
 from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
@@ -22,12 +24,12 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
     """
     :description: 创建微信预订单
     """
-    @filter_check_params("user_id,pay_order_no")
+    @filter_check_params("pay_order_no",check_user_code=True)
     def get_async(self):
         """
         :description: 创建微信预订单
         :param pay_order_no:支付单号
-        :param user_id:用户标识
+        :param user_code:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -63,7 +65,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
             ref_params = {}
             invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
-            return self.response_json_success(invoke_result_data.data)
+            return self.response_json_success(self.business_process_executed(invoke_result_data.data,ref_params={}))
         except Exception as ex:
             self.logging_link_error("【创建微信预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
@@ -182,7 +184,7 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
         :last_editors: HuangJianYi
         """
         req_info_dict = ref_params["req_info_dict"]
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"), context=self)
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
         try:
@@ -192,7 +194,9 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
                 # 退款成功(相关表处理)
                 refund_order_model.update_table("refund_status=3,out_refund_no=%s,refund_date=%s", where="refund_no=%s", params=[req_info_dict["refund_id"], req_info_dict["success_time"], req_info_dict["out_refund_no"]])
                 pay_order_model.update_table("order_status=20,refund_amount=%s", where="pay_order_no=%s", params=[int(req_info_dict["settlement_refund_fee"]) / 100, req_info_dict["out_trade_no"]])
-                db_transaction.commit_transaction()
+                result,message = db_transaction.commit_transaction(True)
+                if result == False:
+                    self.logging_link_error("【微信退款异步通知执行事务失败】" + message)
             else:
                 # 退款失败(只更新退款表)
                 refund_order_model.update_table("refund_status=4", where="out_refund_no=%s", params=req_info_dict["refund_id"])
@@ -207,12 +211,12 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
     """
     :description: 创建抖音预订单
     """
-    @filter_check_params("user_id,pay_order_no")
+    @filter_check_params("pay_order_no",check_user_code=True)
     def get_async(self):
         """
         :description: 创建抖音预订单
         :param pay_order_no:支付单号
-        :param user_id:用户标识
+        :param user_code:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -375,7 +379,7 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
         """
         refund_order = ref_params["refund_order"]
         response_data = ref_params["response_data"]
-        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
+        db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"), context=self)
         pay_order_model = PayOrderModel(db_transaction=db_transaction, context=self)
         refund_order_model = RefundOrderModel(db_transaction=db_transaction, context=self)
         try:
@@ -385,7 +389,9 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
                 # 退款成功(相关表处理)
                 refund_order_model.update_table("refund_status=3,refund_date=%s", where="refund_no=%s", params=[SevenHelper.get_now_datetime(), response_data["cp_refundno"]])
                 pay_order_model.update_table("order_status=20,refund_amount=%s", where="pay_order_no=%s", params=[int(response_data["refund_amount"]) / 100, refund_order.pay_order_no])
-                db_transaction.commit_transaction()
+                result,message = db_transaction.commit_transaction(True)
+                if result == False:
+                    self.logging_link_error("【抖音退款异步通知执行事务失败】" + message)
             else:
                 # 退款失败(只更新退款表)
                 refund_order_model.update_table("refund_status=4", where="refund_no=%s", params=[response_data["cp_refundno"]])
@@ -447,7 +453,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                                 tiktok_goods_id_list = []
                                 if asset_type == 3:
                                     price_base_model = PriceBaseModel(context=self.context)
-                                    price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
+                                    price_gear_dict_list,total = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0)
                                     for price_gear_dict in price_gear_dict_list:
                                         tiktok_goods_id_list.append(price_gear_dict["goods_id"])
                                 else:
@@ -555,4 +561,4 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                 if is_add == True:
                     redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
                     redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
-        return pay_order_no_list,redis_init,pay_order_cache_key
\ No newline at end of file
+        return pay_order_no_list,redis_init,pay_order_cache_key
