@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-10 11:29:31
-@LastEditTime: 2022-06-15 15:46:41
+@LastEditTime: 2022-07-07 17:55:26
 @LastEditors: HuangJianYi
 @Description: 处理数据统计上报
 """
@@ -12,12 +12,12 @@ from seven_cloudapp_frame.models.stat_base_model import *
 
 class ShareReportHandler(ClientBaseHandler):
     """
-    :description: 处理分享上报
+    :description: 处理分享统计上报
     """
     @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
-        :description: 处理分享上报
+        :description: 处理分享统计上报
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
@@ -52,12 +52,12 @@ class ShareReportHandler(ClientBaseHandler):
 
 class InviteReportHandler(ClientBaseHandler):
     """
-    :description: 处理邀请进入上报
+    :description: 处理邀请进入统计上报
     """
     @filter_check_params("login_token", check_user_code=True)
     def get_async(self):
         """
-        :description: 处理邀请进入上报
+        :description: 处理邀请进入统计上报
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
