@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2022-06-22 15:24:55
+@LastEditTime: 2022-07-07 19:09:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -270,7 +270,7 @@ class InviteNewUserHandler(ClientBaseHandler):
     @filter_check_params("invite_user_id,login_token", check_user_code=True)
     def get_async(self):
         """
-        :description: 处理邀请新用户任务
+        :description: 处理邀请用户任务
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
@@ -296,9 +296,16 @@ class InviteNewUserHandler(ClientBaseHandler):
         check_new_user = invoke_result_data.data["check_new_user"] if invoke_result_data.data.__contains__("check_new_user") else True
         continue_request_expire = invoke_result_data.data["continue_request_expire"] if invoke_result_data.data.__contains__("continue_request_expire") else 5
         close_invite_limit = invoke_result_data.data["close_invite_limit"] if invoke_result_data.data.__contains__("close_invite_limit") else False
+
+        stat_base_model = StatBaseModel(context=self.context)
+        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"BeInvitedUserCount": 1, "BeInvitedCount": 1})
+
         invoke_result_data = task_base_model.process_invite_user(app_id, act_id, module_id, user_id, login_token, from_user_id, self.__class__.__name__, self.request_code, check_user_nick, check_new_user, continue_request_expire, close_invite_limit)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            
+        stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, "", {"AddBeInvitedUserCount": 1})
+        
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
