@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:15:49
-@LastEditTime: 2021-11-25 10:41:01
+@LastEditTime: 2022-06-14 15:57:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,7 +15,6 @@ class ThemeInfoHandler(ClientBaseHandler):
     """
     :description: 获取主题（皮肤）信息
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取主题（皮肤）信息
@@ -24,7 +23,7 @@ class ThemeInfoHandler(ClientBaseHandler):
         :return 主题信息
         :last_editors: HuangJianYi
         """
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         ver_no = self.get_param("ver_no")
 
         act_base_model = ActBaseModel(context=self)
@@ -34,7 +33,7 @@ class ThemeInfoHandler(ClientBaseHandler):
         theme_id = act_info_dict["theme_id"]
         theme_base_model = ThemeBaseModel(context=self)
         theme_info = theme_base_model.get_theme_info(theme_id, ver_no)
-        return self.response_json_success(theme_info)
+        return self.response_json_success(self.business_process_executed(theme_info,ref_params={}))
 
 
 class SaveThemeHandler(ClientBaseHandler):
@@ -90,12 +89,13 @@ class SaveSkinHandler(ClientBaseHandler):
         server_json = self.get_param("server_json")
         theme_out_id = self.get_param("theme_out_id")
         skin_out_id = self.get_param("skin_out_id")
+        style_type = self.get_param_int("style_type")
 
         theme_base_model = ThemeBaseModel(context=self)
-        invoke_result_data = theme_base_model.save_skin(app_id, skin_name, client_json, server_json, theme_out_id, skin_out_id)
+        invoke_result_data = theme_base_model.save_skin(app_id, skin_name, client_json, server_json, theme_out_id, skin_out_id, style_type)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success(invoke_result_data.data)
+        return self.response_json_success(self.business_process_executed(invoke_result_data.data, ref_params={}))
 
 
 class ThemeInfoListHandler(ClientBaseHandler):
@@ -111,7 +111,7 @@ class ThemeInfoListHandler(ClientBaseHandler):
         """
         app_id = self.get_source_app_id()
         theme_base_model = ThemeBaseModel(context=self)
-        return self.response_json_success(theme_base_model.get_theme_list(app_id))
+        return self.response_json_success(self.business_process_executed(theme_base_model.get_theme_list(app_id), ref_params={}))
 
 
 class SkinInfoListHandler(ClientBaseHandler):
@@ -128,4 +128,4 @@ class SkinInfoListHandler(ClientBaseHandler):
         """
         theme_out_id = self.get_param("theme_out_id")
         theme_base_model = ThemeBaseModel(context=self)
-        return self.response_json_success(theme_base_model.get_skin_list(theme_out_id))
\ No newline at end of file
+        return self.response_json_success(self.business_process_executed(theme_base_model.get_skin_list(theme_out_id), ref_params={}))
