@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-06-17 17:19:55
+@LastEditTime: 2022-07-07 16:47:46
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -41,7 +41,7 @@ def filter_check_params(must_params=None, check_user_code=False):
                     if not must_param in self.request_params or self.request_params[must_param] == "":
                         self.response_json_error("param_error", f"参数错误,缺少必传参数{must_param}")
                         return
-            if check_user_code == True and not self.get_user_code():
+            if check_user_code == True and not self.get_user_id():
                 self.response_json_error("param_error", f"参数错误,缺少必传参数user_code")
                 return
 
