@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-06-28 19:38:02
+@LastEditTime: 2022-07-07 18:23:12
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -79,20 +79,13 @@ class FrameBaseHandler(BaseApiHandler):
         return
 
     def set_default_headers(self):
-        """
-        :description: 设置默认头部，用于跨域请求
-        :return
-        :last_editors: HuangJianYi
-        """
         allow_origin_list = config.get_value("allow_origin_list")
-        if not allow_origin_list:
-            return
         origin = self.request.headers.get("Origin")
         if origin in allow_origin_list:
             self.set_header("Access-Control-Allow-Origin", origin)
 
         self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
-        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
+        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS,PUT,DELETE")
         self.set_header("Access-Control-Allow-Credentials", "true")
 
     def json_dumps(self, rep_dic):
@@ -160,8 +153,8 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 校验是否加密
         :last_editors: HuangJianYi
         """
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密
         is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
         if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
             return True
@@ -187,7 +180,7 @@ class FrameBaseHandler(BaseApiHandler):
             if not app_id:
                 app_id = config.get_value("app_id")
             password = str(encrypt_key).replace("1", "l")
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
                     json_params = json.loads(self.request.body)
                     if json_params:
@@ -232,7 +225,7 @@ class FrameBaseHandler(BaseApiHandler):
                     return invoke_result_data
 
         else:
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
                     json_params = json.loads(self.request.body)
                     if json_params:
@@ -429,14 +422,18 @@ class FrameBaseHandler(BaseApiHandler):
         :last_editors: HuangJianYi
         """
         #当有参数app_id时，优先取app_id，然后在是source_app_id
-        if self.get_param("app_id"):
-            source_app_id = self.get_param("app_id")
+        source_app_id = self.get_param("app_id")
+        if source_app_id:
             return source_app_id
         source_app_id = self.get_param("source_app_id")
-        #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
-        if source_app_id == config.get_value("client_template_id") or source_app_id == "":
-            test_config = config.get_value("test_config",{})
-            source_app_id = test_config.get("source_app_id","")
+        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
+        if plat_type == 1:
+            #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
+            if source_app_id == config.get_value("client_template_id") or source_app_id == "":
+                test_config = config.get_value("test_config",{})
+                source_app_id = test_config.get("source_app_id","")
+        else:
+            source_app_id = config.get_value("app_id")
         return source_app_id
 
     def get_app_id(self):
@@ -449,16 +446,16 @@ class FrameBaseHandler(BaseApiHandler):
         app_id = self.get_param("app_id")
         if app_id == "":
             plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
-            user_nick = self.get_user_nick()
-            if user_nick and plat_type == 1:
-                store_user_nick = user_nick.split(':')[0]
-                if store_user_nick:
-                    app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
-                    if app_info_dict:
-                        app_id = app_info_dict["app_id"]
+            if plat_type == 1:
+                user_nick = self.get_user_nick()
+                if user_nick:
+                    store_user_nick = user_nick.split(':')[0]
+                    if store_user_nick:
+                        app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
+                        if app_info_dict:
+                            app_id = app_info_dict["app_id"]
             else:
                 app_id = config.get_value("app_id")
-
         return app_id
 
     def get_access_token(self):
@@ -505,7 +502,7 @@ class FrameBaseHandler(BaseApiHandler):
         operation_log_model = OperationLogModel(context=self)
 
         operation_log.app_id = ""
-        operation_log.act_id = int(self.get_param("act_id", 0))
+        operation_log.act_id = self.get_act_id()
         operation_log.open_id = self.get_open_id()
         operation_log.user_nick = self.get_user_nick()
         operation_log.request_params = self.request_params
@@ -633,36 +630,6 @@ class ClientBaseHandler(FrameBaseHandler):
                 self.request_code = UUIDHelper.get_uuid()
             self.logging_link_error("【客户端handler基类】" + traceback.format_exc())
 
-    def get_online_url(self, act_id, app_id, module_id=0):
-        """
-        :description: 获取online_url
-        :param act_id:活动标识
-        :param app_id:应用标识
-        :param module_id:模块标识
-        :param page:跳转的首页地址pages/index/index
-        :return str
-        :last_editors: HuangJianYi
-        """
-        page_index = ""
-        page = config.get_value("page_index")
-        if page:
-            page_index = "&page=" + CodingHelper.url_encode(page)
-        query = CodingHelper.url_encode(f"actid={act_id}")
-        if module_id > 0:
-            query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
-        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
-        return online_url
-
-    def get_live_url(self, app_id):
-        """
-        :description: 获取live_url
-        :param app_id:应用标识
-        :return str
-        :last_editors: HuangJianYi
-        """
-        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
-        return live_url
-
     def get_device_info_dict(self):
         """
         :description: 获取头部参数字典
