@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 17:00:55
-@LastEditTime: 2022-02-18 14:13:24
+@LastEditTime: 2022-06-14 14:05:36
 @LastEditors: HuangJianYi
 @Description: 基础模块
 """
@@ -188,8 +188,8 @@ class CmsInfoListHandler(ClientBaseHandler):
             order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "id desc"
             field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
         cms_base_model = CmsBaseModel(context=self)
-        page_info = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False)
-        page_info.data = self.business_process_executed(page_info.data, ref_params={})
+        page_list, total = cms_base_model.get_cms_info_list(place_id=place_id, page_size=page_size, page_index=page_index, order_by=order_by, field=field, app_id=app_id, act_id=act_id, is_cache=False)
+        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
         return self.response_json_success(page_info)
 
 
@@ -214,4 +214,3 @@ class GetProductPriceHandler(ClientBaseHandler):
             return self.response_json_error("error", "产品价格信息格式有误")
 
         return self.reponse_json_success(product_price)
-
