@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-30 15:46:34
-@LastEditTime: 2022-06-13 14:31:55
+@LastEditTime: 2022-06-30 13:45:13
 @LastEditors: HuangJianYi
 @Description: 投放模块
 """
@@ -38,8 +38,9 @@ class InitLaunchGoodsHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        online_url = self.get_online_url(act_id, app_id, module_id)
+        app_base_model = AppBaseModel(context=self)
         launch_base_model = LaunchBaseModel(context=self)
+        online_url = app_base_model.get_online_url(act_id, app_id, module_id)
         invoke_result_data = launch_base_model.init_launch_goods(app_id, act_id, source_types, online_url)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -196,7 +197,8 @@ class AsyncLaunchGoodsHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        online_url = self.get_online_url(act_id, app_id, module_id)
+        app_base_model = AppBaseModel(context=self)
+        online_url = app_base_model.get_online_url(act_id, app_id, module_id)
         launch_base_model = LaunchBaseModel(context=self)
 
         app_key, app_secret = self.get_app_key_secret()
