@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2021-11-29 16:40:32
+@LastEditTime: 2022-06-13 14:39:20
 @LastEditors: HuangJianYi
 @Description: 任务模块
 """
@@ -17,7 +17,6 @@ class TaskInfoListHandler(ClientBaseHandler):
     """
     :description: 获取任务列表
     """
-    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取任务列表
@@ -29,7 +28,7 @@ class TaskInfoListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         is_release = int(self.get_param("is_release", -1))
         task_base_model = TaskBaseModel(context=self)
@@ -40,7 +39,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
     """
     :description 保存任务
     """
-    @filter_check_params("act_id,task_list")
+    @filter_check_params("task_list")
     def post_async(self):
         """
         :description: 保存任务
@@ -52,7 +51,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_app_id()
-        act_id = int(self.get_param("act_id", 0))
+        act_id = self.get_act_id()
         module_id = int(self.get_param("module_id", 0))
         task_list = self.get_param("task_list")
         try:
@@ -106,4 +105,3 @@ class SaveTaskInfoHandler(ClientBaseHandler):
         task_base_model._delete_task_info_dependency_key(act_id)
 
         return self.response_json_success()
-
