@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2022-06-20 14:19:39
+@LastEditTime: 2022-07-01 11:08:29
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -495,4 +495,41 @@ class SevenHelper:
             birthday_dict["year"] = card_id[6:10]
             birthday_dict["month"] = card_id[10:12]
             birthday_dict["day"] = card_id[12:14]
-        return birthday_dict
\ No newline at end of file
+        return birthday_dict
+
+    @classmethod
+    def get_enum_key(self, enum_class, enum_value, default_value=''):
+        """
+        :description: 根据枚举值获取枚举key
+        :param enum_class:枚举类
+        :param enum_value:枚举值
+        :param default_value:默认值
+        :return:str
+        :last_editors: HuangJianYi
+        """
+        try:
+            enum = enum_class(enum_value)
+            if enum:
+                return enum.name
+            else:
+                return default_value
+        except:
+            return default_value
+
+    @classmethod
+    def get_enum_value(self, enum_class, enum_key, default_value=''):
+        """
+        :description: 根据枚举key获取枚举值
+        :param enum_class:枚举类
+        :param enum_value:枚举key
+        :param default_value:默认值
+        :return:str
+        :last_editors: HuangJianYi
+        """
+        try:
+            for enum in enum_class:
+                if enum.name == enum_key:
+                    return enum.value
+            return default_value
+        except:
+            return default_value
\ No newline at end of file
