@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:54:51
-@LastEditTime: 2022-03-09 09:23:09
+@LastEditTime: 2022-06-30 13:42:37
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -243,3 +243,33 @@ class AppBaseModel():
             app_info.last_login_date = login_log.create_date if login_log else ""
             invoke_result_data.data = app_info
             return invoke_result_data
+    
+    def get_online_url(self, act_id, app_id, module_id=0):
+        """
+        :description: 获取online_url
+        :param act_id:活动标识
+        :param app_id:应用标识
+        :param module_id:模块标识
+        :param page:跳转的首页地址pages/index/index
+        :return str
+        :last_editors: HuangJianYi
+        """
+        page_index = ""
+        page = config.get_value("page_index")
+        if page:
+            page_index = "&page=" + CodingHelper.url_encode(page)
+        query = CodingHelper.url_encode(f"actid={act_id}")
+        if module_id > 0:
+            query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
+        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
+        return online_url
+
+    def get_live_url(self, app_id):
+        """
+        :description: 获取live_url
+        :param app_id:应用标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
+        return live_url
\ No newline at end of file
