@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-03-06 23:17:54
-@LastEditTime: 2022-05-24 10:43:51
+@LastEditTime: 2022-06-07 11:10:02
 @LastEditors: HuangJianYi
 :Description: 数据缓存业务模型
 """
@@ -25,7 +25,7 @@ class CacheModel(BaseModel):
         self.cache_prefix = "data_cache"
         super(CacheModel,self).__init__(model_class, sub_table)
 
-    def __get_dependency_key(self, dependency_key=''):
+    def get_dependency_key(self, dependency_key=''):
         """
         :Description: 获取依赖建
         :param dependencyKey: 依赖键
@@ -36,9 +36,10 @@ class CacheModel(BaseModel):
             dependency_key = self.table_name.lower()
         return self.cache_prefix + ":" + "dependency_" + dependency_key
 
-    def __get_cache_key(self, field, where='', group_by='', order_by='', limit='', params=None):
+    def get_cache_key(self, prefix_key, field, where='', group_by='', order_by='', limit='', params=None):
         """
         :Description: 获取缓存key
+        :param prefix_key: 缓存key前缀[entity、entityone、entitylist、entitypagelist、total、dict、dictone、dictlist、dictpagelist]
         :param field: 查询字段
         :param where: 数据库查询条件语句
         :param group_by: GROUP BY 语句
@@ -55,10 +56,10 @@ class CacheModel(BaseModel):
                     params_str += "_" + str(param)
             else:
                 params_str += "_" + str(params)
-        cache_key = str(field + "_" + where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower()
-        return CryptoHelper.md5_encrypt(cache_key)
+        suffix_key = CryptoHelper.md5_encrypt(str(field + "_" + where + "_" + group_by + "_" + order_by + "_" + limit + params_str).replace(" ", "").lower())
+        return prefix_key + "_" + self.table_name + "_" + suffix_key
 
-    def __get_dependency_cache_key(self, dependency_key, cache_key):
+    def get_dependency_cache_key(self, dependency_key, cache_key):
         """
         :Description: 获取依赖缓存key
         :param dependency_key: 依赖键
@@ -68,7 +69,7 @@ class CacheModel(BaseModel):
         """
         return self.cache_prefix + ":" + CryptoHelper.md5_encrypt(dependency_key+cache_key)
 
-    def __get_dependency_cache(self, dependency_key, cache_key):
+    def get_dependency_cache(self, dependency_key, cache_key):
         """
         :Description: 获取依赖缓存值
         :param dependency_key: 依赖键
@@ -76,7 +77,7 @@ class CacheModel(BaseModel):
         :return: 依赖缓存值
         :last_editors: HuangJianYi
         """
-        dependency_cache_key = self.__get_dependency_cache_key(dependency_key,cache_key)
+        dependency_cache_key = self.get_dependency_cache_key(dependency_key,cache_key)
         redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
@@ -105,7 +106,7 @@ class CacheModel(BaseModel):
             cache_data = json.loads(cache_data)
             return cache_data
 
-    def __set_dependency_cache(self, dependency_key, cache_key,value, cache_expire):
+    def set_dependency_cache(self, dependency_key, cache_key, value, cache_expire):
         """
         :Description: 设置依赖缓存值
         :param dependency_key: 依赖键
@@ -122,7 +123,7 @@ class CacheModel(BaseModel):
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
             redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=config.get_value("dependency_cache_expire",60*60))
-        dependency_cache_key = self.__get_dependency_cache_key(dependency_key,cache_key)
+        dependency_cache_key = self.get_dependency_cache_key(dependency_key,cache_key)
         redis_init.set(dependency_cache_key + "_savetime",str(TimeHelper.get_now_format_time()),ex=cache_expire)
         return redis_init.set(dependency_cache_key,JsonHelper.json_dumps(value),ex=cache_expire)
 
@@ -158,13 +159,13 @@ class CacheModel(BaseModel):
                     time.sleep(delay_delete_time)
                 if isinstance(dependency_key,list):
                     for key in dependency_key:
-                        is_del = redis_init.delete(self.__get_dependency_key(key))
+                        is_del = redis_init.delete(self.get_dependency_key(key))
                         if is_del == 1:
                             success_count += 1
                     if success_count == len(dependency_key):
                         break
                 else:
-                    success_count = redis_init.delete(self.__get_dependency_key(dependency_key))
+                    success_count = redis_init.delete(self.get_dependency_key(dependency_key))
                     if success_count == 1:
                         break
             except:
@@ -195,9 +196,9 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entitylist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
-        list_row = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('entitylist',field,where,group_by,order_by,limit,params)
+        list_row = self.get_dependency_cache(dependency_key,cache_key)
         if list_row and config.get_value("is_redis_cache",True) == True:
             if list_row == 'null':
                 return None
@@ -207,7 +208,10 @@ class CacheModel(BaseModel):
             cache_value = deepcopy(list_row)
             if not cache_value:
                 cache_value = None
-            self.__set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
             return self._BaseModel__row_entity_list(list_row)
 
     def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=600):
@@ -236,9 +240,9 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit};"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entitypagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
-        page_list = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('entitypagelist',field,where,group_by,order_by,limit,params)
+        page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return self._BaseModel__row_entity_list(page_list["data"]),page_list["row_count"]
         else:
@@ -251,7 +255,10 @@ class CacheModel(BaseModel):
             page_list = {}
             page_list["data"] = list_row
             page_list["row_count"] = row_count
-            self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             return self._BaseModel__row_entity_list(page_list["data"]), row_count
 
     def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=600):
@@ -274,16 +281,19 @@ class CacheModel(BaseModel):
             order_by = " ORDER BY " + order_by
         sql = f"SELECT * FROM {self.table_name}{where}{group_by}{order_by} LIMIT 1;"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entity_" + self.table_name + "_" + self.__get_cache_key('*',where,group_by,order_by,'1',params)
-        one_row = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('entity','*',where,group_by,order_by,'1',params)
+        one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
     def get_cache_entity_by_id(self, primary_key_id, dependency_key='', cache_expire=600):
@@ -299,16 +309,19 @@ class CacheModel(BaseModel):
         params = [primary_key_id]
         sql = f"SELECT * FROM {self.table_name} WHERE {where} LIMIT 1;"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "entityone_" + self.table_name + "_" + self.__get_cache_key('*',where,'','','',params)
-        one_row = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('entityone','*',where,'','','',params)
+        one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return self._BaseModel__row_entity(one_row)
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
     def get_cache_total(self, where='', group_by='', field=None, params=None,dependency_key='', cache_expire=600):
@@ -331,9 +344,9 @@ class CacheModel(BaseModel):
             field = self.primary_key_field
         sql = f"SELECT COUNT({field}) AS count FROM {self.table_name}{where}{group_by};"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "total_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,'','',params)
-        total = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('total',field,where,group_by,'','',params)
+        total = self.get_dependency_cache(dependency_key,cache_key)
         if total and config.get_value("is_redis_cache",True) == True:
             if total == '0':
                 return 0
@@ -342,7 +355,10 @@ class CacheModel(BaseModel):
         else:
             list_row = self.db.fetch_one_row(sql, params)
             if list_row and 'count' in list_row:
-                self.__set_dependency_cache(dependency_key,cache_key,list_row['count'],cache_expire)
+                config_cache_expire = config.get_value("cache_expire",0)
+                if config_cache_expire > 0:
+                    cache_expire = config_cache_expire
+                self.set_dependency_cache(dependency_key,cache_key,list_row['count'],cache_expire)
                 return list_row['count']
             return 0
 
@@ -372,9 +388,9 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit}"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dict_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
-        one_row = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('dict',field,where,group_by,order_by,limit,params)
+        one_row = self.get_dependency_cache(dependency_key,cache_key)
 
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
@@ -382,7 +398,10 @@ class CacheModel(BaseModel):
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql, params)
-            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             if one_row:
                 for field in one_row:
                     one_row[field] = self._BaseModel__convert_field_type(one_row[field])
@@ -402,16 +421,19 @@ class CacheModel(BaseModel):
         params = [primary_key_id]
         sql = f"SELECT {field} FROM {self.table_name} WHERE {where} LIMIT 1;"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictone_" + self.table_name + "_" + self.__get_cache_key(field,where,'','','',params)
-        one_row = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('dictone',field,where,'','','',params)
+        one_row = self.get_dependency_cache(dependency_key,cache_key)
         if one_row and config.get_value("is_redis_cache",True) == True:
             if one_row == 'null':
                 return None
             return one_row
         else:
             one_row = self.db.fetch_one_row(sql,params)
-            self.__set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             if one_row:
                 for field in one_row:
                     one_row[field] = self._BaseModel__convert_field_type(one_row[field])
@@ -441,14 +463,17 @@ class CacheModel(BaseModel):
             limit = " LIMIT "+str(limit)
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by}{limit};"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictlist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
-        list = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('dictlist',field,where,group_by,order_by,limit,params)
+        list = self.get_dependency_cache(dependency_key,cache_key)
         if list and config.get_value("is_redis_cache",True) == True:
             return list
         else:
             list = self.db.fetch_all_rows(sql, params)
-            self.__set_dependency_cache(dependency_key,cache_key,list,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,list,cache_expire)
             if list and len(list) > 0:
                 for one_row in list:
                     for field in one_row:
@@ -480,9 +505,9 @@ class CacheModel(BaseModel):
         sql = f"SELECT {field} FROM {self.table_name}{where}{group_by}{order_by} LIMIT {limit}"
         count_sql = f"SELECT COUNT({self.primary_key_field}) AS count FROM {self.table_name}{where}{group_by};"
 
-        dependency_key = self.__get_dependency_key(str(dependency_key))
-        cache_key = "dictpagelist_" + self.table_name + "_" + self.__get_cache_key(field,where,group_by,order_by,limit,params)
-        page_list = self.__get_dependency_cache(dependency_key,cache_key)
+        dependency_key = self.get_dependency_key(str(dependency_key))
+        cache_key = self.get_cache_key('dictpagelist',field,where,group_by,order_by,limit,params)
+        page_list = self.get_dependency_cache(dependency_key,cache_key)
         if page_list and config.get_value("is_redis_cache",True) == True:
             return page_list["data"],page_list["row_count"]
         else:
@@ -495,9 +520,13 @@ class CacheModel(BaseModel):
             page_list = {}
             page_list["data"] = list_row
             page_list["row_count"] = row_count
-            self.__set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
+            config_cache_expire = config.get_value("cache_expire",0)
+            if config_cache_expire > 0:
+                cache_expire = config_cache_expire
+            self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             if list_row and len(list_row) > 0:
                 for one_row in list_row:
                     for field in one_row:
                         one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return list_row, row_count
+    
\ No newline at end of file
