@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-26 10:22:44
-@LastEditTime: 2022-04-28 16:23:23
+@LastEditTime: 2022-06-14 14:02:35
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -141,9 +141,10 @@ class CmsBaseModel():
         :return:
         :last_editors: HuangJianYi
         """
-        page_info = PageInfo(page_index, page_size, 0, [])
+        page_list = []
+        total = 0
         if not place_id:
-            return page_info
+            return page_list, total
         condition = "place_id=%s and is_release=1"
         params = [place_id]
         if act_id:
@@ -157,5 +158,4 @@ class CmsBaseModel():
             page_list, total = cms_info_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params,dependency_key=f"cms_info_list:placeid_{place_id}",cache_expire=600)
         else:
             page_list, total = cms_info_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=condition, group_by="", order_by=order_by,params=params)
-        page_info = PageInfo(page_index, page_size, total, page_list)
-        return page_info
+        return page_list, total
