@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-06-02 18:16:27
+@LastEditTime: 2022-06-16 09:41:13
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -60,7 +60,6 @@ class StatConsoleModel():
                 time.sleep(0.1)
                 db_transaction = DbTransaction(db_config_dict=config.get_value("db_cloudapp"))
                 stat_queue_model = StatQueueModel(db_transaction=db_transaction)
-                del_stat_queue_model = StatQueueModel(sub_table="del", db_transaction=db_transaction)
                 stat_orm_model = StatOrmModel()
                 now_date = TimeHelper.get_now_format_time()
                 if mod_count == 1:
@@ -124,7 +123,6 @@ class StatConsoleModel():
                                     stat_report_model.update_table(f"key_value=key_value+{stat_queue.key_value}", stat_report_condition, params=stat_report_param)
                                 stat_log_model.add_entity(stat_log)
                             stat_queue_model.del_entity("id=%s", params=[stat_queue.id])
-                            del_stat_queue_model.add_entity(stat_queue)
                             result,message = db_transaction.commit_transaction(True)
                             if result == False:
                                 raise Exception("执行事务失败", message)
