@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 09:24:43
-@LastEditTime: 2022-06-23 11:02:32
+@LastEditTime: 2022-07-06 14:28:58
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -244,6 +244,55 @@ class OrderBaseModel(FrameBaseModel):
             return invoke_result_data
         prize_order_model.update_table("seller_remark=%s,modify_date=%s", "id=%s", [seller_remark, now_datetime, prize_order_id])
         return invoke_result_data
+    
+    def update_prize_order_receive_address(self, app_id, act_id, prize_order_id, province=None, city=None, county=None, street=None, address=None, real_name=None, telephone=None):
+        """
+        :description: 更新用户奖品订单收货地址
+        :param app_id：应用标识
+        :param act_id：活动标识
+        :param prize_order_id：奖品订单标识
+        :param province:省
+        :param city:市
+        :param county:区县
+        :param street:街道
+        :param address:地址
+        :param real_name:用户名
+        :param telephone:电话
+        :return: 实体模型InvokeResultData
+        :last_editors: HuangJianYi
+        """
+
+        now_datetime = SevenHelper.get_now_datetime()
+        prize_order_model = PrizeOrderModel(sub_table=self.get_business_sub_table("prize_order_tb", {"act_id": act_id, "user_id": 0}),context=self.context)
+        invoke_result_data = InvokeResultData()
+
+        prize_order = prize_order_model.get_entity_by_id(prize_order_id)
+        if not prize_order:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-1"
+            return invoke_result_data
+        if prize_order.app_id != app_id:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "error"
+            invoke_result_data.error_message ="奖品订单信息不存在-2"
+            return invoke_result_data
+        if province != None:
+            prize_order.province = province
+        if city != None:
+            prize_order.city = city
+        if county != None:
+            prize_order.county = county
+        if street != None:
+            prize_order.street = street
+        if address != None:
+            prize_order.address = address
+        if real_name != None:
+            prize_order.real_name = real_name
+        if telephone != None:
+            prize_order.telephone = telephone
+        prize_order_model.update_table("province=%s,city=%s,county=%s,street=%s,address=%s,real_name=%s,telephone=%s,modify_date=%s", "id=%s", [prize_order.province, prize_order.city, prize_order.county, prize_order.street, prize_order.address, prize_order.real_name, prize_order.telephone, now_datetime, prize_order_id])
+        return invoke_result_data
 
     def import_prize_order(self, app_id, act_id, content_type, content, ref_head_name='小程序订单号', prize_roster_sub_table=None):
         """
