@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-02-28 11:53:29
+@LastEditTime: 2022-07-07 17:57:42
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -328,15 +328,13 @@ class StatBaseModel(FrameBaseModel):
             key_list_dict = {}
             invoke_result_data = self.business_process_executing(app_id,act_id,module_id,user_id,login_token,handler_name,True,check_user_nick,continue_request_expire,acquire_lock_name)
             if invoke_result_data.success == True:
-                act_info_dict = invoke_result_data.data["act_info_dict"]
-                act_module_dict = invoke_result_data.data["act_module_dict"]
-                user_info_dict = invoke_result_data.data["user_info_dict"]
                 identifier = invoke_result_data.data["identifier"]
                 if is_stat == True:
                     key_list_dict["AddBeInvitedUserCount"] = 1 #从分享进入新增用户数
             if is_stat == True:
                 key_list_dict["BeInvitedUserCount"] = 1  #从分享进入用户数
                 key_list_dict["BeInvitedCount"] = 1  #从分享进入次数
+            if key_list_dict:
                 stat_base_model.add_stat_list(app_id, act_id, module_id, user_id, open_id, key_list_dict)
         except Exception as ex:
             if self.context:
