@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-04-16 14:38:22
-@LastEditTime: 2022-03-08 17:34:29
+@LastEditTime: 2022-06-27 15:54:06
 @LastEditors: HuangJianYi
 :Description: 基础路由   业务方可以直接使用语句 handlers.extend(seven_cloudapp_frame.route.seven_cloudapp_frame_route()) 引入
 """
@@ -92,6 +92,9 @@ def seven_cloudapp_frame_route():
         (r"/server/version_upgrade", app_s.VersionUpgradeHandler),  #小程序端版本升级
         (r"/server/update_telephone", app_s.UpdateTelephoneHandler),  #更新手机号
         (r"/server/get_short_url", app_s.GetShortUrlHandler),  #淘宝短链接
+        (r"/server/update_store_asset", app_s.UpdateStoreAssetHandler),  #更新商家资产值
+        (r"/server/store_asset_list", app_s.StoreAssetListHandler),  #商家资产列表
+        (r"/server/store_asset_log_list", app_s.StoreAssetLogListHandler),  #商家资产流水列表
         (r"/server/act_type_list", act_s.ActTypeListHandler),  #活动类型列表
         (r"/server/next_progress", act_s.NextProgressHandler),  #活动下一步操作
         (r"/server/add_act_info", act_s.AddActInfoHandler),  #添加活动
@@ -145,6 +148,9 @@ def seven_cloudapp_frame_route():
         (r"/server/update_theme", theme_s.UpdateThemeHandler),  #更新主题
         (r"/server/theme_info_list", theme_s.ThemeInfoListHandler),  #主题信息列表
         (r"/server/skin_info_list", theme_s.SkinInfoListHandler),  #皮肤信息列表
+        (r"/server/save_ip_type", ip_s.SaveIpTypeHandler),  #保存ip类型
+        (r"/server/ip_type_list", ip_s.IpTypeListHandler),  #ip类型列表
+        (r"/server/release_ip_type", ip_s.ReleaseIpTypeHandler),  #上下架ip类型
         (r"/server/save_ip_info", ip_s.SaveIpInfoHandler),  #保存ip信息
         (r"/server/delete_ip_info", ip_s.DeleteIpInfoHandler),  #删除ip信息
         (r"/server/ip_info_list", ip_s.IpInfoListHandler),  #ip信息列表
